@@ -1,17 +1,15 @@
 from __future__ import annotations
 
-
 from typing import Any
 
+from . import gql_mutations as gm
+from . import gql_queries as gq
 from .const import ENDPOINT
 from .exception_classes import ErrorMSG, LoginError, NoAdminError
 from .graphql_client import GraphqlClient
 from .handler_gql import HandlerGQL
 from .status import EmailAndPhoneVerificationTypeV2, NormalStatus, UserContactType
 
-from . import gql_mutations as gm
-from . import gql_queries as gq
-
 
 class GQLHandler(HandlerGQL):
     def __init__(
@@ -89,7 +87,9 @@ class GQLHandler(HandlerGQL):
             if self.userId == id:
                 if contact["guardianType"] == "FIRST":
                     data: dict[str, Any] = (await self.runAuthorizedGqlQuery_a(query, variables, key)).get("data", {})
-                    return data.get(key, False)
+                    for k in data.keys():
+                        if k.upper() == key.upper():
+                            return data.get(k, False)
         raise NoAdminError()
 
     ########## SECTION QUERY start ##########
